from cli import cli

if __name__ == "__main__":
    cli()


# same logger for different files
# modules and packages?
# why i cant import this here -> from cloner.cli import cli  ?
# https://docs.python.org/3/tutorial/modules.html#packages
